@@ -1,8 +1,8 @@
-# Copyright (c) $YEAR$ Timothy Appnel
+# Copyright (c) 2004 Timothy Appnel
 # http://www.timaoutloud.org/
 # This code is released under the Artistic License.
 #
-# $PACKAGE$ - $ABSTRACT$ 
+# XML::Elemental::Node - Base class for all other XML::Elemental objects.
 # 
 
 package XML::Elemental::Node;
@@ -25,20 +25,18 @@ sub stash {
 
 1;
 
+__END__
 
 =begin
 
 =head1 NAME
 
-$PACKAGE$ - $ABSTRACT$
+XML::Elemental::Node - Base class for all other XML::Elemental objects.
 
-=head1 SYNOPSIS
+=head1 AUTHOR & COPYRIGHT
 
-=head1 DESCRIPTION
-
-=head1 DEPENDENCIES
-
-=head1 SEE ALSO
+Please see the XML::Elemental manpage for author, copyright, and
+license information.
 
 =cut
 
